isLowEnd property
bool
get
isLowEnd
Returns true if the device is classified as low-end.
Implementation
static bool get isLowEnd => deviceTier == DeviceTier.low;
Returns true if the device is classified as low-end.
static bool get isLowEnd => deviceTier == DeviceTier.low;